JarResult class

Constructors

JarResult({required bool isValid, String? error, Map<String, dynamic>? details})
JarResult.error(String message, [Map<String, dynamic>? details])
factory
JarResult.success()
factory

Properties

details Map<String, dynamic>?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited