JarSchema<T, Self extends JarSchema<T, Self> > class
abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- self → Self
-
no setter
-
transformers
→ List<
JarValueTransformer< T> > -
final
-
validators
→ List<
JarValidator< T> > -
final
Methods
-
addValidator(
JarValidator< T> validator) → Self -
getAllValues(
) → Map< String, dynamic> ? -
getFieldValue(
String fieldName) → T? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
JarValueTransformer< T> transformer) → Self -
validate(
T? value, [Map< String, dynamic> ? allValues]) → JarResult -
when(
String field, Map< dynamic, Self Function(Self)> conditions) → Self
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited