Jar class

Constructors

Jar()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

array<T>([JarSchema<T, JarSchema<T, dynamic>>? elementSchema]) JarArray<T>
boolean() JarBoolean
date() JarDate
mixed<T>() JarMixed<T>
number() JarNumber
object([Map<String, JarSchema<dynamic, JarSchema>>? fields]) JarObject
string() JarString