JarArray<T> class

Inheritance

Constructors

JarArray(JarSchema<T, JarSchema<T, dynamic>>? elementSchema)

Properties

elementSchema JarSchema<T, JarSchema<T, dynamic>>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self JarArray<T>
no setterinherited
transformers List<JarValueTransformer<List<T>>>
finalinherited
validators List<JarValidator<List<T>>>
finalinherited

Methods

addValidator(JarValidator<List<T>> validator) JarArray<T>
inherited
custom(String? validator(List<T>? value), [String? message]) JarArray<T>
equalTo(String field, [String? message]) JarArray<T>
getFieldValue(String fieldName) List<T>?
inherited
length(int exactLength, [String? message]) JarArray<T>
max(int length, [String? message]) JarArray<T>
min(int length, [String? message]) JarArray<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optional() JarArray<T>
required([String? message]) JarArray<T>
toString() String
A string representation of this object.
inherited
transform(JarValueTransformer<List<T>> transformer) JarArray<T>
inherited
unique([String? message]) JarArray<T>
validate(dynamic value, [Map<String, dynamic>? allValues]) JarResult
override
when(String field, Map<dynamic, JarArray<T> Function(JarArray<T>)> conditions) JarArray<T>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited