JarBoolean class

Inheritance

Constructors

JarBoolean()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self JarBoolean
no setterinherited
transformers List<JarValueTransformer<bool>>
finalinherited
validators List<JarValidator<bool>>
finalinherited

Methods

addValidator(JarValidator<bool> validator) JarBoolean
inherited
custom(String? validator(bool? value, [Map<String, dynamic>? allValues]), [String? message]) JarBoolean
equalTo(String field, [String? message]) JarBoolean
getAllValues() Map<String, dynamic>?
inherited
getFieldValue(String fieldName) bool?
inherited
isFalse([String? message]) JarBoolean
isTrue([String? message]) JarBoolean
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optional() JarBoolean
required([String? message]) JarBoolean
toString() String
A string representation of this object.
inherited
transform(JarValueTransformer<bool> transformer) JarBoolean
inherited
validate(bool? value, [Map<String, dynamic>? allValues]) JarResult
inherited
when(String field, Map<dynamic, JarBoolean Function(JarBoolean)> conditions) JarBoolean
override

Operators

operator ==(Object other) bool
The equality operator.
inherited