JarDate class

Inheritance

Constructors

JarDate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self JarDate
no setterinherited
transformers List<JarValueTransformer<DateTime>>
finalinherited
validators List<JarValidator<DateTime>>
finalinherited

Methods

addValidator(JarValidator<DateTime> validator) JarDate
inherited
custom(String? validator(DateTime? value, [Map<String, dynamic>? allValues]), [String? message]) JarDate
equalTo(String field, [String? message]) JarDate
future([String? message]) JarDate
getAllValues() Map<String, dynamic>?
inherited
getFieldValue(String fieldName) DateTime?
inherited
max(DateTime max, [String? message]) JarDate
min(DateTime min, [String? message]) JarDate
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optional() JarDate
past([String? message]) JarDate
required([String? message]) JarDate
toString() String
A string representation of this object.
inherited
transform(JarValueTransformer<DateTime> transformer) JarDate
inherited
validate(DateTime? value, [Map<String, dynamic>? allValues]) JarResult
inherited
when(String field, Map<dynamic, JarDate Function(JarDate)> conditions) JarDate
override

Operators

operator ==(Object other) bool
The equality operator.
inherited