JarMixed<T> class

Inheritance

Constructors

JarMixed()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self JarMixed<T>
no setterinherited
transformers List<JarValueTransformer<T>>
finalinherited
validators List<JarValidator<T>>
finalinherited

Methods

addValidator(JarValidator<T> validator) JarMixed<T>
inherited
custom(String? validator(T? value, [Map<String, dynamic>? allValues]), [String? message]) JarMixed<T>
equalTo(String field, [String? message]) JarMixed<T>
getAllValues() Map<String, dynamic>?
inherited
getFieldValue(String fieldName) → T?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notOneOf(List<T> forbiddenValues, [String? message]) JarMixed
oneOf(List<T> allowed, [String? message]) JarMixed
optional() JarMixed
required([String? message]) JarMixed
toString() String
A string representation of this object.
inherited
transform(JarValueTransformer<T> transformer) JarMixed<T>
inherited
validate(T? value, [Map<String, dynamic>? allValues]) JarResult
inherited
when(String field, Map<dynamic, JarMixed<T> Function(JarMixed<T>)> conditions) JarMixed<T>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited